# Generated by Django 3.1 on 2021-05-11 13:43

import django.db.models.deletion
import django.utils.timezone
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('testapp', '0003_modelwithfktoself'),
    ]

    operations = [
        migrations.AlterField(
            model_name='commoninfobasedmodel',
            name='created_at',
            field=models.DateTimeField(db_index=True, default=django.utils.timezone.now, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='commoninfobasedmodel',
            name='created_by',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name='testapp_commoninfobasedmodel_created',
                to=settings.AUTH_USER_MODEL,
                verbose_name='Created by',
            ),
        ),
        migrations.AlterField(
            model_name='commoninfobasedmodel',
            name='lastmodified_at',
            field=models.DateTimeField(
                db_index=True, default=django.utils.timezone.now, verbose_name='Last modified at'
            ),
        ),
        migrations.AlterField(
            model_name='commoninfobasedmodel',
            name='lastmodified_by',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name='testapp_commoninfobasedmodel_lastmodified',
                to=settings.AUTH_USER_MODEL,
                verbose_name='Last modified by',
            ),
        ),
    ]
